==> campsite-2.4.1.tar.gz: campsite/implementation/management/priv/lang/sh/users.php <==
<?php
regGS("That user name already exists, please choose a different login name.", "Korsničko ime već postoji, smislite nešto drugo.");
regGS("User may delete article attachments", "Korisnik može da briše atačmente uz članke.");
regGS("User may change article attachments", "Korsnik može da menja atačmente uz članke");
regGS("User may add article attachments", "Korsinik može da dodaje atačmente uz članke");
regGS("Staff management", "Upravljanje saradničkim nalozima");
regGS("Subscriber management", "Upravljanje pretplatničkim nalozima");
regGS("Account Name", "Ime naloga");
regGS("Full Name", "Puno ime");
regGS("Delete user $1", "Obriši korisnika $1");
regGS("User list is empty.", "Lista korisnika je prazna.");
regGS("You do not have the right to create user accounts.", "Nemate pravo da kreirate korisničke naloge.");
regGS("Title", "Zvanje");
regGS("Gender", "Pol");
regGS("Mr.", "gospodin");
regGS("Mrs.", "gospođa");
regGS("Ms.", "gospođica");
regGS("Dr.", "doktor");
regGS("Male", "muški");
regGS("Female", "ženski");
regGS("under 18", "ispod 18");
regGS("Age", "Starost");
regGS("Confirm password", "Potvrdi lozinku");
regGS("E-Mail", "E-pošta");
regGS("City", "Grad");
regGS("Street Address", "Ulična adresa");
regGS("Postal Code", "Poštanski broj");
regGS("State", "Provincija/region");
regGS("Phone", "Telefon");
regGS("Fax", "Faks");
regGS("Contact Person", "Osoba za kontakt");
regGS("Second Phone", "Alternativni telefon");
regGS("Employer", "Poslodavac");
regGS("Employer Type", "Tip poslodavca");
regGS("Corporate", "Komercijalna delatnost");
regGS("Non-Governmental Organisation", "Nevladina organizacija");
regGS("Government Agency", "Vladina agencija");
regGS("Academic", "Akademska ustanova");
regGS("Media", "Medijska kuća");
regGS("Position", "Pozicija");
regGS("Show more user details", "Prikaži dodatne podatke o korsniku");
regGS("Hide user details", "Sakrij podatke o korisniku");
regGS("You must select a $1", "Morate izabrati $1");
regGS("The password must be at least 6 characters long and both passwords should match.", "Lozinka mora biti dugačka najmanje 6 karaktera i obe lozinke se moraju poklapati");
regGS("The user account could not be created.", "Korisnički nalog ne može biti kreiran");
regGS("User account $1 was created successfully.", "Korisnički nalog $1 je uspešno napravljen.");
regGS("Click here to change password", "Kliknite ovde za promenu lozinke");
regGS("Old Password", "Stara lozinka");
regGS("You do not have the right to change user account permissions.", "Nemate pravo da menjate dodeljena prava za korisničke naloge");
regGS("Permissions for $1 changed", "Dodeljena prava za $1 su izmenjena");
regGS("You do not have the right to change user account information.", "Nemate pravo da promenite podatke za korisnički nalog");
regGS("Click here to customize user permissions", "Kliknite ovde za izmenu prava korsnika");
regGS("Click here to use existing user type permissions (discard customization)", "Kliknite ovde za korišćenje postojećih prava za tip korisnika (poništava izmene)");
regGS("Click here to leave password unchanged", "Kliknite ovde da ostavite lozinku neizmenjenu");
regGS("User account information changed for $1", "Podaci za korisnički nalog $1 su promenjeni");
regGS("The password you typed is incorrect.", "Lozinka koju ste uneli je neispravna");
regGS("You do not have the right to delete user accounts.", "Nemate pravo da brišete korisničke naloge");
regGS("Are you sure you want to delete the user account $1 ?", "Da li ste sigurni da želite da obrišete korisnički nalog $1?");
regGS("User account $1 was deleted successfully.", "Korisnički nalog $1 je uspešno obrisan.");
regGS("User IP access list management", "Upravljanje listom pristupa preko korisničkih IP adresa");
regGS("No records.", "Bez podataka");
regGS("Start IP", "Početna IP adresa");
regGS("Number of addresses", "Broj adresa");
regGS("The IP Group $1 has been created.", "Grupa zasnovana na IP adresi je kreirana");
regGS("There was an error creating the IP address group.", "Došlo je do greške pri kreiranju grupe zasnovane na IP adresi.");
regGS("Are you sure you want to delete the IP Group $1?", "Sigurni ste da želite da obrišete IP grupu $1?");
regGS("The IP address group $1 has been deleted.", "Grupa zasnovana na IP adresi $1 je obrisana");
regGS("User '$1' information was changed successfully.", "Podaci o korisniku '$1' su uspešno promenjeni.");
regGS("IP address", "IP adresa");
regGS("fill in from left to right at least one input box", "popunite sa leva na desno najmanje jedno polje");
regGS("User Type", "Tip korisnika");
regGS("You must input a valid EMail address.", "Morate uneti ispravnu e-mail adresu.");
regGS("The confirm password must be at least 6 characters long and both passwords should match.", "Lozinka mora biti dugačka najmanje 6 znakova i mora se poklapati sa potvrdom.");
regGS("You must input a number between 0 and 255 into the Start IP address' $1 field.", "Morate uneti broj između 0 i 255 u polje $1kod početne IP adrese ");
regGS("Delete subscriptions to $1", "Obriši pretplate za $1");
regGS("Change user account information", "Promenite podatke za korisnički nalog");
regGS("The IP address group $1:$2 conflicts with another existing group.", "IP adresna grupa  $1:$2 se sukobljava sa drugom, već postojećom grupom.");
regGS("Creation Date", "Datum kreiranja");
regGS("User Name", "Korisničko ime");
regGS("User management", "Administracija korisnicima");
regGS("Set", "Postavi");
regGS("Update", "Izmeni");
regGS("Rights", "Prava");
regGS("IP Access", "IP pristup");
regGS("Staff", "Osoblje");
regGS("Adding new user account", "Dodavanje novog korisničkog naloga");
regGS("You must select an user type.", "Morate izabrati tip korisnika");
regGS("The user account $1 has been created.", "Kreiran je korisnički nalog za $1 ");
regGS("Please check if an account with the same user name does not already exist.", "Proveri da li nalog pod tim korisničkim imenom već ne postoji");
regGS("Change password", "Promeni lozinku");
regGS("You do not have the right to change user passwords.", "Nemate pravo da menjate korisničke lozinke");
regGS("Changing user password", "Menjanje korisničke lozinke");
regGS("The password could not be changed.", "Lozinka ne može biti promenjena");
regGS("The password has been changed.", "Lozinka je promenjena");
regGS("User may manage templates", "Korisnik može da upravlja šablonima");
regGS("User may add/change country entries", "Korisnik može da dodaje/menja podatke o državama");
regGS("Edit user account permissions", "Prikaži dodeljena prava za korisnički nalog");
regGS("This user account does not have permissions information.", "Za ovaj korisnički nalog nema informacija o dodeljenim pravima");
regGS("Updating user account permissions", "Izmena dodeljenih prava za korisnički nalog");
regGS("User account permissions have been successfuly updated.", "Dodeljena prava za korisnički nalog uspešno su izmenjena");
regGS("User account permissions could not be updated.", "Dodeljena prava za korisnički nalog ne mogu biti izmenjena");
regGS("Changing user account information", "Menjanje podataka za korisnički nalog");
regGS("User account information has been changed.", "Podaci za korisnički nalog su promenjeni");
regGS("User account information could not be changed.", "Podaci za korisnički nalog ne mogu biti promenjeni");
regGS("Old password", "Stara lozinka");
regGS("New password", "Nova lozinka");
regGS("Confirm new password", "Potvrdi novu lozinku");
regGS("Changing your password", "Menjanje vaše lozinke");
regGS("User $1 changed his password", "Korisnik $1 je promenio lozinku");
regGS("Delete user account", "Obriši korisnički nalog");
regGS("Deleting user account", "Brisanje korisničkog naloga");
regGS("The user account $1 could not be deleted.", "Korisnički nalog $1 ne može biti obrisan");
regGS("No such user.", "Nema takvog korisnika");
regGS("Delete IP Group $1", "Obriši IP grupu $1");
regGS("IP Access List", "Lista pristupa na osnovu IP adresa");
regGS("Adding new IP Group", "Dodavanje nove grupe zasnovane na IP adresi");
regGS("The IP Group could not be created.", "IP grupa ne može biti kreirana");
regGS("Please check if an account with the same IP Group does not already exist.", "Proverite da li nalog sa istom IP grupom već ne postoji");
regGS("Delete IP Group", "Obriši IP grupu");
regGS("You do not have the right to delete IP Groups.", "Nemate pravo da brišete IP grupe");
regGS("No such IP Group.", "Nema takve IP grupe");
regGS("Deleting IP Group", "Brisanje IP grupe");
regGS("The IP Group could not be deleted.", "IP grupa ne može biti obrisana");
regGS("No IP Group.", "Nema IP grupe");
?>

==> campsite-2.5.1.tar.gz: campsite/implementation/management/priv/lang/sh/users.php <==
<?php
regGS("65 or over", "65 ili više");
regGS("User may translate articles", "Korisnik može da prevodi tekstove");
regGS("User may move articles", "Korisnik može da premešta tekstove");
regGS("User may find and replace", "Korisnik može da koristi opciju 'traži/zameni'");
regGS("User may change system preferences", "Korisnik može da menja sistemske postavke");
regGS("User may attach topics to articles", "Korisnik može da dodaje teme tekstovima");
regGS("User may attach images to articles", "Korisnik može da kači slike uz tekstove");
regGS("User may add special characters", "Korisnik može da dodaje specijalne znakove");
regGS("Reset search form", "Poništi uslove pretrage");
regGS("That user name already exists, please choose a different login name.", "Korsničko ime već postoji, smislite nešto drugo.");
regGS("User may delete article attachments", "Korisnik može da briše fajlove zakačene uz tekstove");
regGS("User may change article attachments", "Korsnik može da menja fajlove prikačene uz tekstove");
regGS("User may add article attachments", "Korsinik može da kači fajlove uz tekstove");
regGS("Staff management", "Upravljanje saradničkim nalozima");
regGS("Subscriber management", "Upravljanje pretplatničkim nalozima");
regGS("Account Name", "Korisničko ime");
regGS("Full Name", "Puno ime");
regGS("Delete user $1", "Obriši korisnika $1");
regGS("User list is empty.", "Lista korisnika je prazna.");
regGS("You do not have the right to create user accounts.", "Nemate pravo da kreirate korisničke naloge.");
regGS("Title", "Zvanje");
regGS("Gender", "Pol");
regGS("Mr.", "gospodin");
regGS("Mrs.", "gospođa");
regGS("Ms.", "gospođica");
regGS("Dr.", "doktor");
regGS("Male", "muški");
regGS("Female", "ženski");
regGS("under 18", "ispod 18");
regGS("Age", "Starost");
regGS("Confirm password", "Potvrdi lozinku");
regGS("E-Mail", "E-pošta");
regGS("City", "Grad");
regGS("Street Address", "Ulična adresa");
regGS("Postal Code", "Poštanski broj");
regGS("State", "Država");
regGS("Phone", "Telefon");
regGS("Fax", "Faks");
regGS("Contact Person", "Osoba za kontakt");
regGS("Second Phone", "Alternativni telefon");
regGS("Employer", "Poslodavac");
regGS("Employer Type", "Tip poslodavca");
regGS("Corporate", "Komercijalna delatnost");
regGS("Non-Governmental Organisation", "Nevladina organizacija");
regGS("Government Agency", "Vladina agencija");
regGS("Academic", "Akademska ustanova");
regGS("Media", "Medijska kuća");
regGS("Position", "Pozicija");
regGS("Show more user details", "Prikaži dodatne podatke o korisniku");
regGS("Hide user details", "Sakrij podatke o korisniku");
regGS("You must select a $1", "Morate izabrati $1");
regGS("The password must be at least 6 characters long and both passwords should match.", "Lozinka mora biti dugačka najmanje 6 karaktera i obe lozinke se moraju poklapati");
regGS("The user account could not be created.", "Korisnički nalog ne može biti kreiran");
regGS("User account $1 was created successfully.", "Korisnički nalog $1 je uspešno napravljen.");
regGS("Click here to change password", "Kliknite ovde za promenu lozinke");
regGS("Old Password", "Stara lozinka");
regGS("You do not have the right to change user account permissions.", "Nemate pravo da menjate dodeljena prava za korisničke naloge");
regGS("Permissions for $1 changed", "Dodeljena prava za $1 su izmenjena");
regGS("You do not have the right to change user account information.", "Nemate pravo da promenite podatke za korisnički nalog");
regGS("Click here to customize user permissions", "Kliknite ovde za izmenu prava korsnika");
regGS("Click here to use existing user type permissions (discard customization)", "Kliknite ovde za korišćenje postojećih prava za tip korisnika (poništava izmene)");
regGS("Click here to leave password unchanged", "Kliknite ovde da ostavite lozinku neizmenjenu");
regGS("User account information changed for $1", "Podaci za korisnički nalog $1 su promenjeni");
regGS("The password you typed is incorrect.", "Lozinka koju ste uneli je neispravna");
regGS("You do not have the right to delete user accounts.", "Nemate pravo da brišete korisničke naloge");
regGS("Are you sure you want to delete the user account $1 ?", "Da li ste sigurni da želite da obrišete korisnički nalog $1?");
regGS("User account $1 was deleted successfully.", "Korisnički nalog $1 je uspešno obrisan.");
regGS("User IP access list management", "Upravljanje listom pristupa preko korisničkih IP adresa");
regGS("No records.", "Bez podataka");
regGS("Start IP", "Početna IP adresa");
regGS("Number of addresses", "Broj adresa");
regGS("The IP Group $1 has been created.", "Grupa zasnovana na IP adresi je kreirana");
regGS("There was an error creating the IP address group.", "Došlo je do greške pri kreiranju grupe zasnovane na IP adresi.");
regGS("Are you sure you want to delete the IP Group $1?", "Sigurni ste da želite da obrišete IP grupu $1?");
regGS("The IP address group $1 has been deleted.", "Grupa zasnovana na IP adresi $1 je obrisana");
regGS("User '$1' information was changed successfully.", "Podaci o korisniku '$1' su uspešno promenjeni.");
regGS("IP address", "IP adresa");
regGS("fill in from left to right at least one input box", "popunite sa leva na desno najmanje jedno polje");
regGS("User Type", "Tip korisnika");
regGS("You must input a valid EMail address.", "Morate uneti ispravnu e-mail adresu.");
regGS("The confirm password must be at least 6 characters long and both passwords should match.", "Lozinka mora biti dugačka najmanje 6 znakova i mora se poklapati sa potvrdom.");
regGS("You must input a number between 0 and 255 into the Start IP address' $1 field.", "Morate uneti broj između 0 i 255 u polje $1kod početne IP adrese ");
regGS("Delete subscriptions to $1", "Obriši pretplate za $1");
regGS("Change user account information", "Promenite podatke za korisnički nalog");
regGS("The IP address group $1:$2 conflicts with another existing group.", "IP adresna grupa  $1:$2 se sukobljava sa drugom, već postojećom grupom.");
regGS("Creation Date", "Datum kreiranja");
regGS("User Name", "Korisničko ime");
regGS("User management", "Administracija korisnicima");
regGS("Set", "Postavi");
regGS("Update", "Izmeni");
regGS("Rights", "Prava");
regGS("IP Access", "IP pristup");
regGS("Staff", "Osoblje");
regGS("Adding new user account", "Dodavanje novog korisničkog naloga");
regGS("You must select an user type.", "Morate izabrati tip korisnika");
regGS("The user account $1 has been created.", "Kreiran je korisnički nalog za $1 ");
regGS("Please check if an account with the same user name does not already exist.", "Proveri da li nalog pod tim korisničkim imenom već ne postoji");
regGS("Change password", "Promeni lozinku");
regGS("You do not have the right to change user passwords.", "Nemate pravo da menjate korisničke lozinke");
regGS("Changing user password", "Menjanje korisničke lozinke");
regGS("The password could not be changed.", "Lozinka ne može biti promenjena");
regGS("The password has been changed.", "Lozinka je promenjena");
regGS("User may manage templates", "Korisnik može da upravlja šablonima");
regGS("User may add/change country entries", "Korisnik može da dodaje/menja podatke o državama");
regGS("Edit user account permissions", "Prikaži dodeljena prava za korisnički nalog");
regGS("This user account does not have permissions information.", "Za ovaj korisnički nalog nema informacija o dodeljenim pravima");
regGS("Updating user account permissions", "Izmena dodeljenih prava za korisnički nalog");
regGS("User account permissions have been successfuly updated.", "Dodeljena prava za korisnički nalog uspešno su izmenjena");
regGS("User account permissions could not be updated.", "Dodeljena prava za korisnički nalog ne mogu biti izmenjena");
regGS("Changing user account information", "Menjanje podataka za korisnički nalog");
regGS("User account information has been changed.", "Podaci za korisnički nalog su promenjeni");
regGS("User account information could not be changed.", "Podaci za korisnički nalog ne mogu biti promenjeni");
regGS("Old password", "Stara lozinka");
regGS("New password", "Nova lozinka");
regGS("Confirm new password", "Potvrdi novu lozinku");
regGS("Changing your password", "Menjanje vaše lozinke");
regGS("User $1 changed his password", "Korisnik $1 je promenio lozinku");
regGS("Delete user account", "Obriši korisnički nalog");
regGS("Deleting user account", "Brisanje korisničkog naloga");
regGS("The user account $1 could not be deleted.", "Korisnički nalog $1 ne može biti obrisan");
regGS("No such user.", "Nema takvog korisnika");
regGS("Delete IP Group $1", "Obriši IP grupu $1");
regGS("IP Access List", "Lista pristupa na osnovu IP adresa");
regGS("Adding new IP Group", "Dodavanje nove grupe zasnovane na IP adresi");
regGS("The IP Group could not be created.", "IP grupa ne može biti kreirana");
regGS("Please check if an account with the same IP Group does not already exist.", "Proverite da li nalog sa istom IP grupom već ne postoji");
regGS("Delete IP Group", "Obriši IP grupu");
regGS("You do not have the right to delete IP Groups.", "Nemate pravo da brišete IP grupe");
regGS("No such IP Group.", "Nema takve IP grupe");
regGS("Deleting IP Group", "Brisanje IP grupe");
regGS("The IP Group could not be deleted.", "IP grupa ne može biti obrisana");
regGS("No IP Group.", "Nema IP grupe");
?>
